Pylons Support
==============

In this module are controllers and other support code for using
ORDF with `Pylons`_.

.. toctree::
   :maxdepth: 2

   ordf_pylons_controllers
   ordf_pylons_serialiser

.. _Pylons: http://pylonshq.com/